==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/Kokkos/KokkosTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Kokkos::kokkoscore" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkoscore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkoscore PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkoscore.so.15.0"
  IMPORTED_SONAME_RELEASE "libkokkoscore.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkoscore )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkoscore "${_IMPORT_PREFIX}/lib/libkokkoscore.so.15.0" )

# Import target "Kokkos::kokkoscontainers" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkoscontainers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkoscontainers PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkoscontainers.so.15.0"
  IMPORTED_SONAME_RELEASE "libkokkoscontainers.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkoscontainers )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkoscontainers "${_IMPORT_PREFIX}/lib/libkokkoscontainers.so.15.0" )

# Import target "Kokkos::kokkosalgorithms" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkosalgorithms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkosalgorithms PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkosalgorithms.so.15.0"
  IMPORTED_SONAME_RELEASE "libkokkosalgorithms.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkosalgorithms )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkosalgorithms "${_IMPORT_PREFIX}/lib/libkokkosalgorithms.so.15.0" )

# Import target "Kokkos::kokkossimd" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkossimd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkossimd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkossimd.so.15.0"
  IMPORTED_SONAME_RELEASE "libkokkossimd.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkossimd )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkossimd "${_IMPORT_PREFIX}/lib/libkokkossimd.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Kokkos/KokkosTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Kokkos::kokkoscore" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkoscore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkoscore PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkoscore.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libkokkoscore.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkoscore )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkoscore "${_IMPORT_PREFIX}/lib/libkokkoscore.so.15.1.1" )

# Import target "Kokkos::kokkoscontainers" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkoscontainers APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkoscontainers PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkoscontainers.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libkokkoscontainers.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkoscontainers )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkoscontainers "${_IMPORT_PREFIX}/lib/libkokkoscontainers.so.15.1.1" )

# Import target "Kokkos::kokkosalgorithms" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkosalgorithms APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkosalgorithms PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkosalgorithms.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libkokkosalgorithms.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkosalgorithms )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkosalgorithms "${_IMPORT_PREFIX}/lib/libkokkosalgorithms.so.15.1.1" )

# Import target "Kokkos::kokkossimd" for configuration "RELEASE"
set_property(TARGET Kokkos::kokkossimd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Kokkos::kokkossimd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkokkossimd.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libkokkossimd.so.15"
  )

list(APPEND _cmake_import_check_targets Kokkos::kokkossimd )
list(APPEND _cmake_import_check_files_for_Kokkos::kokkossimd "${_IMPORT_PREFIX}/lib/libkokkossimd.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
